@@ -1,14 +1,12 @@
 package Dancer2::Plugin::Cache::CHI;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Dancer plugin to cache response content (and anything else)
-$Dancer2::Plugin::Cache::CHI::VERSION = '1.7.0';
+$Dancer2::Plugin::Cache::CHI::VERSION = '1.7.1';
 use strict;
 use warnings;
 use Carp;
 use CHI;
 
-use Dancer2 0.162000;
-
 use Dancer2::Plugin;
 
 register_hook 'before_create_cache';
@@ -17,7 +15,7 @@ register_hook 'before_create_cache';
 my %cache;
 my $cache_page; # actually hold the ref to the args
 my $cache_page_key_generator = sub {
-    return $_[0]->request->path;
+    return $_[0]->app->request->path;
 };
 
 on_plugin_import {
@@ -56,10 +54,10 @@ sub _create_cache {
     my $namespace = shift;
     my $args = shift || {};
 
-    $dsl->execute_hook( 'before_create_cache' );
+    $dsl->execute_hook( 'plugin.cache_chi.before_create_cache' );
 
     my %setting = %{
-        $dsl->dancer_app->config->{plugins}{'Cache::CHI'} || {}
+        $dsl->app->config->{plugins}{'Cache::CHI'} || {}
     };
 
     $setting{namespace} = $namespace if defined $namespace;
@@ -91,7 +89,7 @@ register check_page_cache => sub {
 
         if ( $honor_no_cache ) {
 
-            my $req =  $dsl->request;
+            my $req =  $dsl->app->request;
 
             no warnings 'uninitialized';
 
@@ -173,7 +171,7 @@ Dancer2::Plugin::Cache::CHI - Dancer plugin to cache response content (and anyth
 
 =head1 VERSION
 
-version 1.7.0
+version 1.7.1
 
 =head1 SYNOPSIS
 
